@@ -3,12 +3,16 @@
 #undef HAVE_GETTEXT
 #undef HAVE_LC_MESSAGES
 #undef HAVE_STPCPY
+#undef USE_PYTHON
+#undef USE_DEBUG
+#undef USE_PTHREAD
 #undef USE_GNOME
 #undef USE_PERL
 #undef USE_PLUGIN
 #undef USE_IMLIB
 #undef USE_PANEL
+#undef USE_MYGLIB
 #undef SOCKS
+#undef PREFIX
 #undef VERSION
 #undef PACKAGE
-
